//! BLAS tests

pub mod lapack;

